// Copyright 2010 Jochen Becher
//
// This file is part of MovieSchedule.
//
// MovieSchedule is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// MovieSchedule is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with MovieSchedule.  If not, see <http://www.gnu.org/licenses/>.

#include "settings.h"

Settings::Settings()
    : _location(),
    _previous_locations(),
    _gps_enabled(true),
    _search_objects_type(MOVIES),
    _rotation_mode(AUTOROTATION)
{
}

void Settings::SetPreviousLocations(const Locations &previous_locations)
{
    _previous_locations = previous_locations;
}
